@@ -5,7 +5,7 @@ use strict;
 use warnings;
 use v5.10.0;
 
-our $VERSION = '0.005';
+our $VERSION = '0.006';
 
 use Carp;
 use Mastodon::Types qw( Acct Account DateTime Image URI Instance );
@@ -480,7 +480,8 @@ for my $action (qw(
   *{ __PACKAGE__ . "::" . $action } = sub {
     my $self = shift;
     state $check = compile(Optional [HashRef]);
-    my $params = $check->(@_) // {};
+    my ($params) = $check->(@_);
+    $params //= {};
 
     return $self->get( $action, $params );
   };
@@ -1213,6 +1214,8 @@ C<#> character). This argument is mandatory.
 In addition to the global GET parameters, this method accepts the following
 parameters:
 
+Accessing the public timelines does not require authentication.
+
 =over 4
 
 =item B<local>
@@ -1246,6 +1249,9 @@ the particular tag.
 For more details on how to use this object, see the documentation for
 L<Mastodon::Listener>.
 
+Accessing streaming public timeline will not require authentication (but as
+of this writing still does).
+
 =back
 
 =head1 REQUEST METHODS
