@@ -1,6 +1,6 @@
 package Mastodon::Entity::Report;
 
-our $VERSION = '0.005';
+our $VERSION = '0.006';
 
 use strict;
 use warnings;
@@ -8,9 +8,9 @@ use warnings;
 use Moo;
 with 'Mastodon::Role::Entity';
 
-use Types::Standard qw( Int Any );
+use Types::Standard qw( Int Bool );
 
 has id           => ( is => 'ro', isa => Int );
-has action_taken => ( is => 'ro', isa => Any, required => 1 ); # What is this?
+has action_taken => ( is => 'ro', isa => Bool, required => 1 );
 
 1;
