@@ -1,6 +1,6 @@
 package Mastodon::Role::UserAgent;
 
-our $VERSION = '0.005';
+our $VERSION = '0.006';
 
 use strict;
 use warnings;
@@ -167,8 +167,8 @@ sub _request {
       if ($url !~ /oauth/ and $self->coerce_entities) {
         use Mastodon::Types qw( to_Entity );
         $data = (ref $data eq 'ARRAY')
-          ? [ map { to_Entity($_) } @{$data} ]
-          : to_Entity($data);
+          ? [ map { to_Entity({ %{$_}, _client => $self }) } @{$data} ]
+          : to_Entity({ %{$data}, _client => $self });
       }
     }
 
